@@ -24,8 +24,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -52,7 +52,7 @@ class Alarms:
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if lower_alarm_interval_index is not None:
             self._values["lower_alarm_interval_index"] = lower_alarm_interval_index
         if upper_alarm_interval_index is not None:
@@ -64,7 +64,8 @@ class Alarms:
         stability
         :stability: experimental
         """
-        return self._values.get("lower_alarm_interval_index")
+        result = self._values.get("lower_alarm_interval_index")
+        return result
 
     @builtins.property
     def upper_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
@@ -72,12 +73,13 @@ class Alarms:
         stability
         :stability: experimental
         """
-        return self._values.get("upper_alarm_interval_index")
+        result = self._values.get("upper_alarm_interval_index")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -93,7 +95,10 @@ class Alarms:
 )
 class ArbitraryIntervals:
     def __init__(
-        self, *, absolute: bool, intervals: typing.List["ScalingInterval"]
+        self,
+        *,
+        absolute: builtins.bool,
+        intervals: typing.List["ScalingInterval"],
     ) -> None:
         """
         :param absolute: 
@@ -102,18 +107,20 @@ class ArbitraryIntervals:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "absolute": absolute,
             "intervals": intervals,
         }
 
     @builtins.property
-    def absolute(self) -> bool:
+    def absolute(self) -> builtins.bool:
         """
         stability
         :stability: experimental
         """
-        return self._values.get("absolute")
+        result = self._values.get("absolute")
+        assert result is not None, "Required property 'absolute' is missing"
+        return result
 
     @builtins.property
     def intervals(self) -> typing.List["ScalingInterval"]:
@@ -121,12 +128,14 @@ class ArbitraryIntervals:
         stability
         :stability: experimental
         """
-        return self._values.get("intervals")
+        result = self._values.get("intervals")
+        assert result is not None, "Required property 'intervals' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -156,7 +165,7 @@ class CompleteScalingInterval:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "lower": lower,
             "upper": upper,
         }
@@ -169,7 +178,9 @@ class CompleteScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("lower")
+        result = self._values.get("lower")
+        assert result is not None, "Required property 'lower' is missing"
+        return result
 
     @builtins.property
     def upper(self) -> jsii.Number:
@@ -177,7 +188,9 @@ class CompleteScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("upper")
+        result = self._values.get("upper")
+        assert result is not None, "Required property 'upper' is missing"
+        return result
 
     @builtins.property
     def change(self) -> typing.Optional[jsii.Number]:
@@ -185,12 +198,13 @@ class CompleteScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("change")
+        result = self._values.get("change")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -200,7 +214,7 @@ class CompleteScalingInterval:
 
 
 @jsii.interface(jsii_type="@aws-cdk/aws-autoscaling-common.IRandomGenerator")
-class IRandomGenerator(jsii.compat.Protocol):
+class IRandomGenerator(typing_extensions.Protocol):
     """
     stability
     :stability: experimental
@@ -211,7 +225,7 @@ class IRandomGenerator(jsii.compat.Protocol):
         return _IRandomGeneratorProxy
 
     @jsii.member(jsii_name="nextBoolean")
-    def next_boolean(self) -> bool:
+    def next_boolean(self) -> builtins.bool:
         """
         stability
         :stability: experimental
@@ -236,10 +250,10 @@ class _IRandomGeneratorProxy:
     :stability: experimental
     """
 
-    __jsii_type__ = "@aws-cdk/aws-autoscaling-common.IRandomGenerator"
+    __jsii_type__: typing.ClassVar[str] = "@aws-cdk/aws-autoscaling-common.IRandomGenerator"
 
     @jsii.member(jsii_name="nextBoolean")
-    def next_boolean(self) -> bool:
+    def next_boolean(self) -> builtins.bool:
         """
         stability
         :stability: experimental
@@ -280,7 +294,7 @@ class ScalingInterval:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "change": change,
         }
         if lower is not None:
@@ -304,7 +318,9 @@ class ScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("change")
+        result = self._values.get("change")
+        assert result is not None, "Required property 'change' is missing"
+        return result
 
     @builtins.property
     def lower(self) -> typing.Optional[jsii.Number]:
@@ -318,7 +334,8 @@ class ScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("lower")
+        result = self._values.get("lower")
+        return result
 
     @builtins.property
     def upper(self) -> typing.Optional[jsii.Number]:
@@ -332,12 +349,13 @@ class ScalingInterval:
         stability
         :stability: experimental
         """
-        return self._values.get("upper")
+        result = self._values.get("upper")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
